macro_rules! or_break {
($label:tt, $expr:expr $(,)?) => { ... };
($expr:expr $(,)?) => { ... };
}Expand description
Unwrap on success, or log the failure and break.
Accepts an optional ’label as the first argument.
macro_rules! or_break {
($label:tt, $expr:expr $(,)?) => { ... };
($expr:expr $(,)?) => { ... };
}Unwrap on success, or log the failure and break.
Accepts an optional ’label as the first argument.